@@ -1,4 +1,3 @@
-library(tibble)
 context("fill_na() & count_gaps() for a tsibble")
 
 idx_day <- seq.Date(ymd("2017-01-01"), ymd("2017-01-20"), by = 4)
@@ -11,6 +10,12 @@ test_that("a tbl_df/data.frame", {
   expect_error(fill_na(dat_x), "data.frame")
 })
 
+test_that("unknown interval", {
+  tsbl <- as_tsibble(dat_x[1, ], index = date)
+  expect_error(fill_na(tsbl), "data of unknown interval.")
+  expect_error(count_gaps(tsbl), "data of unknown interval.")
+})
+
 test_that("an irregular tbl_ts", {
   tsbl <- as_tsibble(dat_x, index = date, regular = FALSE)
   expect_error(fill_na(tsbl), "irregular")
@@ -65,6 +70,16 @@ dat_x <- tibble(
 dat_y <- dat_x[c(2:8, 10), ]
 tsbl <- as_tsibble(dat_y, key = id(group), index = date)
 
+test_that("fill_na() for corner case", {
+  expect_identical(fill_na(tsbl[1:5, ]), tsbl[1:5, ])
+})
+
+test_that("fill_na() for yearquarter", {
+  full_tsbl <- tourism %>%
+    fill_na()
+  expect_is(full_tsbl$Quarter, "yearquarter")
+})
+
 test_that("fill_na() for a grouped_ts", {
   full_tsbl <- tsbl %>%
     group_by(group) %>%
