@@ -28,14 +28,12 @@ test_that("if it's a tibble", {
 
 test_that("if it's a tsibble", {
   expect_is(tsbl[, c(1, 2)], "tbl_ts")
-  expect_warning(tsbl[, c(1, 2), drop = TRUE])
+  expect_warning(tsbl[c("group", "date"), drop = TRUE], "`drop` is ignored.")
   expect_error(tsbl[FALSE, ], "empty")
   expect_identical(tsbl[TRUE, ], tsbl)
   tsbl2 <- tsbl[1, ]
   expect_is(tsbl2, "tbl_ts")
   expect_true(is_regular(tsbl2))
-  expect_warning(w_tsbl <- tsbl[sample(nrow(tsbl)), ], "not sorted")
-  expect_is(w_tsbl, "tbl_ts")
 })
 
 dat_x <- tibble(
@@ -49,8 +47,10 @@ test_that("Subset 2 nested variable in a tsibble", {
   tsbl <- as_tsibble(dat_x, key = id(group | level), index = date)
   tsbl2 <- tsbl[, c(1, 2, 4)]
   expect_is(tsbl2, "tbl_ts")
+  expect_is(tsbl2[c("date", "group", "value")], "tbl_ts")
   expect_identical(key_vars(tsbl2)[[1]], "group")
   expect_is(tsbl[, c(1, 3, 4)], "tbl_df")
+  expect_is(tsbl[c("date", "level", "value")], "tbl_df")
 })
 
 dat_x <- tribble(
