@@ -4,26 +4,32 @@ test_that("a tsibble with different frequnecy", {
   x1 <- ts(1:10)
   tsbl1 <- as_tsibble(x1)
   y1 <- as.ts(tsbl1)
-  expect_identical(x1, y1)
+  expect_equal(x1, y1)
   expect_equal(frequency(y1), 1)
   expect_equal(start(y1), c(1, 1))
   x2 <- ts(1:10, start = 2000)
   tsbl2 <- as_tsibble(x2)
   y2 <- as.ts(tsbl2)
-  expect_identical(x2, y2)
+  expect_equal(x2, y2)
   expect_equal(start(y2), c(2000, 1))
   x3 <- ts(1:10, start = c(2000, 1), frequency = 4)
   tsbl3 <- as_tsibble(x3)
   y3 <- as.ts(tsbl3)
-  expect_identical(x3, y3)
+  expect_equal(x3, y3)
   expect_equal(frequency(y3), 4)
   expect_equal(start(y3), c(2000, 1))
   x4 <- ts(1:10, start = c(2000, 1), frequency = 12)
   tsbl4 <- as_tsibble(x4)
   y4 <- as.ts(tsbl4)
-  expect_identical(x4, y4)
+  expect_equal(x4, y4)
   expect_equal(frequency(y4), 12)
   expect_equal(start(y4), c(2000, 1))
+  tsbl5 <- tsbl4 %>% 
+    mutate(value2 = rnorm(10))
+  expect_equal(ncol(as.ts(tsbl5)), 2)
+  expect_is(as.ts(tsbl5), "mts")
+  expect_equal(NCOL(as.ts(tsbl5, value = value2)), 1)
+  expect_is(as.ts(tsbl5, value = value2), "ts")
 })
 
 test_that("a tsibble with a single key", {
